#define BUILD_NUMBER \
	"build-16724464"
#define BUILD_NUMBER_NUMERIC \
	16724464
#define BUILD_NUMBER_NUMERIC_STRING \
	"16724464"
#define PRODUCT_BUILD_NUMBER \
	"product-build-22735"
#define PRODUCT_BUILD_NUMBER_NUMERIC \
	22735
#define PRODUCT_BUILD_NUMBER_NUMERIC_STRING \
	"22735"
